@@ -9,7 +9,7 @@ use File::Spec();
 
 my $SEP = File::Spec->catfile('', '');
 
-our $VERSION = '0.000007';
+our $VERSION = '0.000008';
 
 our %FILES;
 
@@ -59,17 +59,27 @@ sub extract {
     my ($file) = @_;
 
     # No hope :-(
-    return if $file =~ m/^\(eval \d+\)$/;
+    return if $file =~ m/^\(eval( \d+\)?)$/;
 
     # Easy
     return $file if -e $file;
 
     # Moose like to write "blah blah (defined at filename line 123)"
-    return $1 if $file =~ m/defined at (.+) line \d+/;
+    return $1 if $file =~ m/(?:defined|declared) (?:at|in) (.+) at line \d+/;
+    return $1 if $file =~ m/(?:defined|declared) (?:at|in) (.+) line \d+/;
+    return $1 if $file =~ m/\(eval \d+\)\[(.+):\d+\]/;
+    return $1 if $file =~ m/\((.+)\) line \d+/;
+    return $1 if $file =~ m/\((.+)\) at line \d+/;
 
     # If we opened a file with 2-arg open
     $file =~ s/^[\+\-]?(?:>|>>|<|\|)[\+\-]?//;
 
+    # These characters are rare in file names, but common in calls where files
+    # could not be determined, so we probably failed to extract. If this
+    # assumption is wrong for someone they can write a custom extract, this is
+    # not a bug.
+    return if $file =~ m/([\[\]\(\)]|->|\beval\b)/;
+
     # If we have a foo.bar pattern, or a string that contains this platforms
     # file separator we will condifer it a valid file.
     return $file if $file =~ m/\S+\.\S+$/i || $file =~ m/\Q$SEP\E/;
@@ -139,6 +149,12 @@ C< # This test covered N source files. >. However tools such as
 L<Test2::Harness::UI> can make full use of the coverage information contained
 in the event.
 
+=head2 NOTE: SYSOPEN HOOK DISABLED
+
+The sysopen hook is currently disabled because of an unknown segv error on some
+platforms. I am not certain if it will be enabled again. calls to subs, and
+calls to open are still hooked.
+
 =head1 INTENDED USE CASE
 
 This tool is not intended to record comprehensive coverage information, if you
